@@ -1,13 +1,12 @@
-from .nmrstar import (nmrstar)
-from . import woof as woofstandard
-from .woofpos import (app, wlist, special, woof)
-from .. import conslist
-from .json import (json, number, whitespace, jsonstring, boolean, null, array, obj)
+#from .. import combinators
+#from . import woof as woofstandard
+#from .woofpos import (app, wlist, special, woof)
+#from .json import (json, number, whitespace, jsonstring, keyword, array, obj)
 
 
 
 def runParser(parser, inp):
-    result = parser.parse(conslist.ConsList(inp, 0), (1, 1))
+    result = combinators.run(parser, inp, (1,1))
     if result.status == 'success':
         return result.value['result']
     elif result.status == 'failure':
@@ -17,7 +16,3 @@ def runParser(parser, inp):
         for (message, (line, column)) in result.value:
             print '  %s at line %i, column %i' % (message, line, column)
         raise ValueError('oops, parsing failed with an error')
-
-
-def runP(parser, inp):
-    return parser.parse(conslist.ConsList(inp, 0), (1, 1))
\ No newline at end of file
